==> zio-aws-batch_2.13-5.17.127.2-sources.jar: zio/aws/batch/model/package.scala <==
package zio.aws.batch
import zio.prelude.Subtype
import zio.aws.batch.model.primitives.{TagValue, TagKey, Integer}
import zio.aws.batch.model.primitives.ImageType.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ImageIdOverride extends Subtype[String]
    type ImageIdOverride = zio.aws.batch.model.primitives.ImageIdOverride.Type
    object ImageType extends Subtype[String]
    type ImageType = zio.aws.batch.model.primitives.ImageType.Type
    object Integer extends Subtype[Int]
    type Integer = zio.aws.batch.model.primitives.Integer.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.batch.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.batch.model.primitives.TagValue.Type
  }
  type ArrayJobStatusSummary = Map[String, Integer]
  type AttemptDetails = List[zio.aws.batch.model.AttemptDetail]
  type ComputeEnvironmentDetailList =
    List[zio.aws.batch.model.ComputeEnvironmentDetail]
  type ComputeEnvironmentOrders =
    List[zio.aws.batch.model.ComputeEnvironmentOrder]
  type DeviceCgroupPermissions =
    List[zio.aws.batch.model.DeviceCgroupPermission]
  type DevicesList = List[zio.aws.batch.model.Device]
  type Ec2ConfigurationList = List[zio.aws.batch.model.Ec2Configuration]
  type EnvironmentVariables = List[zio.aws.batch.model.KeyValuePair]
  type EvaluateOnExitList = List[zio.aws.batch.model.EvaluateOnExit]
  type JobDefinitionList = List[zio.aws.batch.model.JobDefinition]
  type JobDependencyList = List[zio.aws.batch.model.JobDependency]
  type JobDetailList = List[zio.aws.batch.model.JobDetail]
  type JobQueueDetailList = List[zio.aws.batch.model.JobQueueDetail]
  type JobSummaryList = List[zio.aws.batch.model.JobSummary]
  type ListJobsFilterList = List[zio.aws.batch.model.KeyValuesPair]
  type LogConfigurationOptionsMap = Map[String, String]
  type MountPoints = List[zio.aws.batch.model.MountPoint]
  type NetworkInterfaceList = List[zio.aws.batch.model.NetworkInterface]
  type NodePropertyOverrides = List[zio.aws.batch.model.NodePropertyOverride]
  type NodeRangeProperties = List[zio.aws.batch.model.NodeRangeProperty]
  type ParametersMap = Map[String, String]
  type PlatformCapabilityList = List[zio.aws.batch.model.PlatformCapability]
  type ResourceRequirements = List[zio.aws.batch.model.ResourceRequirement]
  type SchedulingPolicyDetailList =
    List[zio.aws.batch.model.SchedulingPolicyDetail]
  type SchedulingPolicyListingDetailList =
    List[zio.aws.batch.model.SchedulingPolicyListingDetail]
  type SecretList = List[zio.aws.batch.model.Secret]
  type ShareAttributesList = List[zio.aws.batch.model.ShareAttributes]
  type StringList = List[String]
  type TagKeysList = List[TagKey]
  type TagrisTagsMap = Map[TagKey, TagValue]
  type TagsMap = Map[String, String]
  type TmpfsList = List[zio.aws.batch.model.Tmpfs]
  type Ulimits = List[zio.aws.batch.model.Ulimit]
  type Volumes = List[zio.aws.batch.model.Volume]
}

==> zio-aws-batch_2.13-5.17.167.1-sources.jar: zio/aws/batch/model/package.scala <==
package zio.aws.batch
import zio.prelude.Subtype
import zio.aws.batch.model.primitives.{TagValue, TagKey, Integer}
import zio.aws.batch.model.primitives.ImageType.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ImageIdOverride extends Subtype[String]
    type ImageIdOverride = zio.aws.batch.model.primitives.ImageIdOverride.Type
    object ImageType extends Subtype[String]
    type ImageType = zio.aws.batch.model.primitives.ImageType.Type
    type Integer = Int
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.batch.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.batch.model.primitives.TagValue.Type
  }
  type ArrayJobStatusSummary = Map[String, Integer]
  type AttemptDetails = List[zio.aws.batch.model.AttemptDetail]
  type ComputeEnvironmentDetailList =
    List[zio.aws.batch.model.ComputeEnvironmentDetail]
  type ComputeEnvironmentOrders =
    List[zio.aws.batch.model.ComputeEnvironmentOrder]
  type DeviceCgroupPermissions =
    List[zio.aws.batch.model.DeviceCgroupPermission]
  type DevicesList = List[zio.aws.batch.model.Device]
  type Ec2ConfigurationList = List[zio.aws.batch.model.Ec2Configuration]
  type EnvironmentVariables = List[zio.aws.batch.model.KeyValuePair]
  type EvaluateOnExitList = List[zio.aws.batch.model.EvaluateOnExit]
  type JobDefinitionList = List[zio.aws.batch.model.JobDefinition]
  type JobDependencyList = List[zio.aws.batch.model.JobDependency]
  type JobDetailList = List[zio.aws.batch.model.JobDetail]
  type JobQueueDetailList = List[zio.aws.batch.model.JobQueueDetail]
  type JobSummaryList = List[zio.aws.batch.model.JobSummary]
  type ListJobsFilterList = List[zio.aws.batch.model.KeyValuesPair]
  type LogConfigurationOptionsMap = Map[String, String]
  type MountPoints = List[zio.aws.batch.model.MountPoint]
  type NetworkInterfaceList = List[zio.aws.batch.model.NetworkInterface]
  type NodePropertyOverrides = List[zio.aws.batch.model.NodePropertyOverride]
  type NodeRangeProperties = List[zio.aws.batch.model.NodeRangeProperty]
  type ParametersMap = Map[String, String]
  type PlatformCapabilityList = List[zio.aws.batch.model.PlatformCapability]
  type ResourceRequirements = List[zio.aws.batch.model.ResourceRequirement]
  type SchedulingPolicyDetailList =
    List[zio.aws.batch.model.SchedulingPolicyDetail]
  type SchedulingPolicyListingDetailList =
    List[zio.aws.batch.model.SchedulingPolicyListingDetail]
  type SecretList = List[zio.aws.batch.model.Secret]
  type ShareAttributesList = List[zio.aws.batch.model.ShareAttributes]
  type StringList = List[String]
  type TagKeysList = List[TagKey]
  type TagrisTagsMap = Map[TagKey, TagValue]
  type TagsMap = Map[String, String]
  type TmpfsList = List[zio.aws.batch.model.Tmpfs]
  type Ulimits = List[zio.aws.batch.model.Ulimit]
  type Volumes = List[zio.aws.batch.model.Volume]
}
